@@ -224,10 +224,9 @@ cmdHintFiles cmd = do
         curdir <- getCurrentDirectory
         -- Ignores home directory when it isn't present.
         home <- catchIOError ((:[]) <$> getHomeDirectory) (const $ return [])
-        b <- doesFileExist ".hlint.yaml"
         implicit <- findM doesFileExist $
-            "HLint.hs" : -- the default in HLint 1.*
             map (</> ".hlint.yaml") (ancestors curdir ++ home) -- to match Stylish Haskell
+            ++ ["HLint.hs"] -- the default in HLint 1.*
         return $ explicit1 ++ maybeToList implicit ++ explicit2
     where
         ancestors = init . map joinPath . reverse . inits . splitPath
