@@ -11,15 +11,16 @@ hsColourHTML = id
 
 #else
 
+import Data.Functor
+import Prelude
+
 import Language.Haskell.HsColour.TTY as TTY
 import Language.Haskell.HsColour.Colourise
 import Language.Haskell.HsColour.CSS as CSS
 
 
 hsColourConsole :: IO (String -> String)
-hsColourConsole = do
-    prefs <- readColourPrefs
-    return $ TTY.hscolour prefs
+hsColourConsole = TTY.hscolour <$> readColourPrefs
 
 hsColourHTML :: String -> String
 hsColourHTML = CSS.hscolour False 1
